
# Type: has drug


connects an entity to a single drug

URI: [biolink:has_drug](https://w3id.org/biolink/vocab/has_drug)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [Drug](Drug.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children

 *  [drug exposure➞has drug](drug_exposure_has_drug.md)

## Used by

 * [DrugExposure](DrugExposure.md)
 * [NamedThing](NamedThing.md)
